@@ -6,6 +6,7 @@ import pygame
 pygame.init()
 from pixeljump.levels.act1 import ActOne
 from pixeljump.levels.act2 import ActTwo
+from pixeljump.levels.act3 import ActThree
 from pixeljump.menu import show_menu
 from pixeljump.settings import load_settings
 from pixeljump.assets import get_sprite_image
@@ -25,10 +26,20 @@ def main():
     pygame.display.set_icon(get_sprite_image("KNIGHT", (32, 32)))
     act = show_menu()
     if act == 0 or act == 1:
-        ActOne().run()
-        ActTwo().run()
-    if act == 2:
-        ActTwo().run()
+        while not (done := ActOne().run()):
+            done = ActOne().run()
+        while not (done := ActTwo().run()):
+            done = ActTwo().run()
+        while not (done := ActThree().run()):
+            done = ActThree().run()
+    elif act == 2:
+        while not (done := ActTwo().run()):
+            done = ActTwo().run()
+        while not (done := ActThree().run()):
+            done = ActThree().run()
+    elif act == 3:
+        while not (done := ActThree().run()):
+            done = ActThree().run()
 
 
 if __name__ == "__main__":
